@@ -1,7 +1,7 @@
 import abc
 
 from galileodb import ExperimentDatabase, Experiment, Telemetry
-from galileodb.model import ExperimentEvent, ServiceRequestTrace
+from galileodb.model import ExperimentEvent, RequestTrace
 
 
 class AbstractTestExperimentDatabase(abc.ABC):
@@ -26,6 +26,43 @@ class AbstractTestExperimentDatabase(abc.ABC):
         self.assertEqual(1., actual.created)
         self.assertEqual('running', actual.status)
 
+    def test_save_experiment_and_get(self):
+        entity = Experiment('exp1', 'exp1-name', 'exp1-creator', 1.1, 2.2, status='FINISHED')
+        self.db.save_experiment(entity)
+        actual = self.db.get_experiment('exp1')
+        self.assertEqual(entity.__dict__, actual.__dict__)
+
+    def test_save_experiment_and_find_all(self):
+        entity1 = Experiment('exp1', 'exp1-name', 'exp1-creator', 1.1, 2.2, status='FINISHED')
+        entity2 = Experiment('exp2', 'exp2-name', 'exp2-creator', 3.3, 4.4, status='RUNNING')
+        self.db.save_experiment(entity1)
+        self.db.save_experiment(entity2)
+
+        experiments = self.db.find_all()
+        self.assertEqual(2, len(experiments))
+        self.assertEqual(entity1.__dict__, experiments[0].__dict__)
+        self.assertEqual(entity2.__dict__, experiments[1].__dict__)
+
+    def test_get_running_experiment(self):
+        entity1 = Experiment('exp1', 'exp1-name', 'exp1-creator', 1.1, 2.2, status='FINISHED')
+        entity2 = Experiment('exp2', 'exp2-name', 'exp2-creator', 3.3, 4.4, status='RUNNING')
+        self.db.save_experiment(entity1)
+        self.db.save_experiment(entity2)
+
+        running = self.db.get_running_experiment()
+
+        self.assertEqual('exp2', running.id)
+
+    def test_get_running_experiment_on_empty_set(self):
+        entity1 = Experiment('exp1', 'exp1-name', 'exp1-creator', 1.1, 2.2, status='FINISHED')
+        entity2 = Experiment('exp2', 'exp2-name', 'exp2-creator', 3.3, 4.4, status='FINISHED')
+        self.db.save_experiment(entity1)
+        self.db.save_experiment(entity2)
+
+        running = self.db.get_running_experiment()
+
+        self.assertIsNone(running)
+
     def test_update_experiment_and_get(self):
         exp = Experiment('expid8', 'test_experiment', 'unittest', 10, None, 1, 'running')
         self.db.save_experiment(exp)
@@ -67,10 +104,10 @@ class AbstractTestExperimentDatabase(abc.ABC):
 
     def test_save_and_touch_and_get_traces(self):
         traces = [
-            ServiceRequestTrace('c1', 's1', 'h1', 1.1, 1.2, 1.3),
-            ServiceRequestTrace('c2', 's2', 'h2', 2.1, 2.2, 2.3),
-            ServiceRequestTrace('c3', 's1', 'h1', 3.1, 3.2, 3.3),
-            ServiceRequestTrace('c1', 's1', 'h1', 4.1, 4.2, 4.3),
+            RequestTrace('req1', 'c1', 's1', 1.1, 1.2, 1.3, server='h1', status=200),
+            RequestTrace('req2', 'c2', 's2', 2.1, 2.2, 2.3, server='h2', status=200),
+            RequestTrace('req3', 'c3', 's1', 3.1, 3.2, 3.3, server='h1', status=200, response='time=123'),
+            RequestTrace('req4', 'c1', 's1', 4.1, 4.2, 4.3, server='h1', status=200),
         ]
 
         self.db.save_experiment(Experiment('exp1', start=1, end=3.5, status='FINISHED'))
@@ -82,9 +119,9 @@ class AbstractTestExperimentDatabase(abc.ABC):
         actual = self.db.get_traces('exp1')
 
         expected = [
-            ServiceRequestTrace('c1', 's1', 'h1', 1.1, 1.2, 1.3, 'exp1'),
-            ServiceRequestTrace('c2', 's2', 'h2', 2.1, 2.2, 2.3, 'exp1'),
-            ServiceRequestTrace('c3', 's1', 'h1', 3.1, 3.2, 3.3, 'exp1'),
+            RequestTrace('req1', 'c1', 's1', 1.1, 1.2, 1.3, server='h1', status=200, exp_id='exp1'),
+            RequestTrace('req2', 'c2', 's2', 2.1, 2.2, 2.3, server='h2', status=200, exp_id='exp1'),
+            RequestTrace('req3', 'c3', 's1', 3.1, 3.2, 3.3, server='h1', status=200, response='time=123', exp_id='exp1')
         ]
 
         self.assertEqual(expected, actual)
